@@ -1,4 +1,5 @@
-from tg import expose, flash, require, request, redirect, tmpl_context, validate
+from tg import expose, flash, require, request, response, redirect, tmpl_context, validate
+from tg.controllers import CUSTOM_CONTENT_TYPE
 from pylons.i18n import ugettext as _, lazy_ugettext as l_
 from pylons.controllers.util import abort
 from repoze.what import predicates
@@ -9,7 +10,8 @@ from libacr.lib import url, get_page_from_urllist, user_can_create_children_in_p
 from base import BaseAdminController, _create_node
 from pages import PagesAdminController
 from slices import SlicesAdminController
-from views import ViewsAdminForm
+from views import ViewsAdminController
+from assets import AssetsController
 
 from tw.api import WidgetsList
 import tw.forms as widgets
@@ -24,6 +26,8 @@ from libacr.model.core import DBSession, User, Group
 from libacr.model.content import Tag, Content, Slice, ContentData, Page
 from libacr.model.user_permission import AcrUserPermission
 
+import mimetypes, base64
+
 __all__ = ['AdminController']
 
 class CreateSliceGroupForm(WidgetsList):
@@ -48,6 +52,7 @@ create_slicegroup_form = widgets.TableForm(fields=CreateSliceGroupForm(), submit
 
 class CreateTagForm(WidgetsList):
     name = widgets.TextField(label_text="Name:", validator=validators.NotEmpty())
+    visibility = widgets.SingleSelectField(label_text="Visibility:", options=['public', 'internal'], default='public')
 create_tag_form = widgets.TableForm(fields=CreateTagForm(), submit_text="Create")
 
 class CreateUserForm(WidgetsList):
@@ -57,7 +62,8 @@ create_user_form = widgets.TableForm(fields=CreateUserForm(), submit_text="Add")
 class AdminController(BaseAdminController):
     pages = PagesAdminController()
     slices = SlicesAdminController()
-    views = ViewsAdminForm()
+    views = ViewsAdminController()
+    assets = AssetsController()
 
     @require(predicates.in_group("acr"))
     @expose('libacr.templates.admin.main')
@@ -125,11 +131,34 @@ class AdminController(BaseAdminController):
         return dict(tags=tags, create_form=create_tag_form,
                      section_title="Tags")
 
+    @expose('libacr.templates.admin.tag_members')
+    @require(predicates.in_group("acr"))
+    def tag_members(self, **kw):
+        tag = DBSession.query(Tag).filter_by(name=kw['tag']).one()
+        contents=tag.contents
+        props=[]
+        i_props = ''
+        for i in contents:
+            i_props = i.data_instance._properties
+            section = i_props.sections()[0]
+            for p in i_props.options(section):
+                    if p not in props:
+                        props.append(p)
+        return dict(tag=tag, props=props, contents=contents, section_title="Tags")
+
     @expose()
     @validate(create_tag_form, error_handler=tags)
     @require(predicates.in_group("acr"))
     def create_tag(self, **kw):
+        visibility = kw.get('visibility', 'public')
+
         t = Tag(name=kw['name'])
+        if visibility != 'public':
+            internal_tags_group = DBSession.query(Group).filter_by(group_name='acr_internal_tags').first()
+            if not internal_tags_group:
+                internal_tags_group = Group(group_name='acr_internal_tags')
+                DBSession.add(internal_tags_group)
+            t.group = internal_tags_group
         DBSession.add(t)
 
         flash('Tag successfully created')
