@@ -91,11 +91,8 @@ def make_directories(dir_list):
 
 class UploadForm(WidgetsList):
     document = widgets.FileField(label_text="File:", validator=validators.FieldStorageUploadConverter(not_empty=True))
-    page = widgets.SingleSelectField(label_text="Page:", options=lambda : [(None, '----------')] + \
-                                                                          [(p.uid, p.title) for p in DBSession.query(Page)])
     path = widgets.SingleSelectField(label_text="Path:", options=get_root_tree, validator=validators.NotEmpty())
-    tags = widgets.MultipleSelectField(label_text='Tags:', options=lambda : (p.name for p in DBSession.query(Tag)))
-upload_form = widgets.TableForm(fields=UploadForm(), submit_text="Upload" )
+upload_form = widgets.TableForm(fields=UploadForm(), submit_text="Upload")
 
 class MkdirForm(WidgetsList):
     path = widgets.HiddenField()
@@ -128,6 +125,7 @@ class RDiskController(TGController):
                 return abort(404, "Path not found")
 
         if not os.path.isdir(node_path):
+            response.last_modified = os.stat(node_path).st_mtime
             response.headers['Content-Type'] = 'text/html'
             etag_cache(str(os.stat(node_path).st_mtime))
             return redirect(url('/site') + request.path_info)
@@ -156,24 +154,16 @@ class RDiskController(TGController):
     @require(predicates.in_group("acr"))
     def upload(self, **kw):
         admin_css.inject()
-
-        if kw.has_key('page'):
-            try:
-                kw['page'] = int(kw['page'])
-            except:
-                del kw['page']
-
-        if not kw.has_key('view'):
-            kw['view'] = 'file'
-
-        upload_form = ViewsManager.create_form(kw['view'], UploadForm)
+        if kw.has_key('path'):
+            if kw['path'].startswith('/') and kw['path'] != '/':
+                kw['path'] = kw['path'][1:]
         return dict(title='File Upload', form=upload_form, values=kw,
                      section_title="Upload a file",action=url("/add_res"))
 
     @expose()
-    @validate(ViewsManager.validator(UploadForm), error_handler=upload)
+    @validate(upload_form, error_handler=upload)
     @require(predicates.in_group("acr"))
-    def add_res(self, document, path, view, page, tags=[], **kw):
+    def add_res(self, document, path, **kw):
         def copy_file_to_dest(doc, dest):
             data = doc.file.read()
             f = open(dest, 'w')
@@ -183,35 +173,12 @@ class RDiskController(TGController):
         rel_path = os.sep + path + os.sep
         full_path = from_url_to_path(rel_path)
         disk_file_path = cleanup_path(full_path + os.sep + document.filename)
-        kw['path'] = url(cleanup_path(rel_path + os.sep + document.filename))
-
-        slice_data = {}
-        slice_data['name'] = cleanup_path(rel_path + os.sep + document.filename)[1:].replace('/', '_')
-        slice_data['zone'] = 'main'
-        slice_data['order'] = 0
-        slice_data['tags'] = tags
-        slice_data['view'] = view
-        slice_data['data'] = ViewsManager.encode(view, kw)
-        slice_data['page'] = page
-        slice_data['skip_permission'] = True
-
-        try:
-            valid_views = [Slice.view == view.name for view in ViewsManager.rdisk_views]
-            cur_entry = Content.find_by_property('path', kw['path'], OType=Slice, views=valid_views)[0]
-            cur_entry = cur_entry.content.get_data_instance_for_lang()
-            cur_entry.value = slice_data['data']
-        except:
-            _create_node(**slice_data)
 
         make_directories(split_path_in_walk(full_path))
         copy_file_to_dest(document, disk_file_path)
 
         flash('Resource successfully loaded')
-        page = DBSession.query(Page).filter_by(uid=page).first()
-        if not page:
-            return redirect(url(rel_path))
-        else:
-            return redirect(page.url)
+        return redirect(url(rel_path))
 
     @expose('libacr.templates.rdisk.form')
     @require(predicates.in_group("acr"))
@@ -242,30 +209,17 @@ class RDiskController(TGController):
     @expose()
     @require(predicates.in_group("managers"))
     def del_res(self, what):
-        def erase_meta(p):
-            cur_entry = p
-            try:
-                valid_views = [Slice.view == view.name for view in ViewsManager.rdisk_views]
-                slices = Content.find_by_property('path', '/rdisk' + p, OType=Slice, views=valid_views)
-                for entry in slices:
-                    DBSession.delete(entry)
-            except:
-                flash('Failed to delete content entry')
-
         def rm_file(p):
             if os.path.isdir(p):
                 for root, dirs, files in os.walk(p, topdown=False):
                     for name in files:
                         f = os.path.join(root, name)
-                        meta_f = from_path_to_url(f)
-                        erase_meta(meta_f)
                         os.remove(f)
                     for name in dirs:
                         os.rmdir(os.path.join(root, name))
                 os.rmdir(p)
             else:
                 os.remove(p)
-                erase_meta(from_path_to_url(p))
 
         full_path = from_url_to_path(what)
         rm_file(full_path)
