@@ -81,7 +81,10 @@ def language():
     try:
         lang = get_lang()
         if lang:
-            langs.append(lang)
+            if isinstance(lang, list):
+                langs.extend(lang)
+            else:
+                langs.append(lang)
     except:
         pass
 
@@ -103,19 +106,19 @@ def language():
     langs.append(tg.config.get('default_language', 'en'))
     return langs
 
-def url(path, *args, **kwargs):
+def url(uri_path, *args, **kwargs):
     acr_root = tg.config.get('acr_root', '')
-    if path[0] == '/':
-        path = acr_root + path
-    path = tg.url(path, *args, **kwargs)
-    return path
+    if uri_path[0] == '/':
+        uri_path = acr_root + uri_path
+    uri_path = tg.url(uri_path, params=kwargs)
+    return uri_path
 
-def rdisk_url(path, *args, **kwargs):
+def rdisk_url(uri_path, *args, **kwargs):
     rdisk_root = tg.config.get('rdisk_root', '')
-    if path[0] == '/':
-        path = rdisk_root + path
-    path = tg.url(path, *args, **kwargs)
-    return path
+    if uri_path[0] == '/':
+        uri_path = rdisk_root + uri_path
+    uri_path = tg.url(uri_path, params=kwargs)
+    return uri_path
 
 def get_slices_with_tag(tag):
     return m_core.DBSession.query(m_cms.Slice).filter(m_cms.Slice.tags.any(name=tag))
@@ -145,7 +148,7 @@ class AcrResourceInjector(object):
             r.inject()
 
 acr_js = tw.api.JSLink(modname=__name__, filename='static/acr.js')
-full_acr_js = AcrResourceInjector([acr_js, jquery_js])
+full_acr_js = AcrResourceInjector([jquery_js, acr_js])
 
 basic_acr_css = tw.api.CSSLink(modname=__name__, filename='static/style.css')
 acr_css = AcrResourceInjector([basic_acr_css])
@@ -209,6 +212,8 @@ icons = {
     'udv_manage':IconLink(modname=__name__,
                         filename='static/icons/udv_manage.png', alt='Manage User Defined Views'),
     'udv_add':IconLink(modname=__name__,
-                        filename='static/icons/udv_add.png', alt='Add User Defined View')
+                        filename='static/icons/udv_add.png', alt='Add User Defined View'),
+    'asset':IconLink(modname=__name__,
+                        filename='static/icons/asset.png', alt='Asset')
 }
 
