@@ -11,6 +11,8 @@ from core import DeclarativeBase, DBSession
 import re
 from ConfigParser import ConfigParser
 from StringIO import StringIO
+from paste.util.multidict import MultiDict
+from attributes import Attribute
 
 tag_content_map = Table('acr_cms_map_content_tag', DeclarativeBase.metadata,
                         Column('tag_uid', Integer, ForeignKey('acr_cms_tag.uid')),
@@ -30,6 +32,7 @@ class Tag(DeclarativeBase):
     tag_group = Column(Integer, ForeignKey('tg_group.group_id'))
     contents = relation('Content', secondary=tag_content_map)
     slices = relation('Slice', secondary=tag_slice_map)
+    group = relation('Group', uselist=False)
 
 class Content(DeclarativeBase):
     __tablename__ = 'acr_cms_content'
@@ -134,6 +137,23 @@ class Content(DeclarativeBase):
                 results.append(entry)
         return results
 
+    def getattr(self, name):
+        attr = DBSession.query(Attribute).filter_by(slice=self)\
+                                         .filter_by(name=name).first()
+        if attr:
+            return attr.value
+        else:
+            return None
+
+    def setattr(self, name, value):
+        attr = DBSession.query(Attribute).filter_by(slice=self)\
+                                         .filter_by(name=name).first()
+        if attr:
+            attr.value = value
+        else:
+            DBSession.add(Attribute(name=name, value=value, slice=self))
+        
+
 class ContentData(DeclarativeBase):
     __tablename__ = 'acr_cms_content_data'
 
@@ -143,14 +163,14 @@ class ContentData(DeclarativeBase):
                                                   order_by=desc('acr_cms_content_data.revision'),
                                                   cascade='all, delete-orphan'))
 
-    lang = Column(Unicode(30), nullable=False, index=True, default='en')
+    lang = Column(Unicode(30), nullable=False, index=True, default=u'en')
     time = Column(DateTime, default=datetime.now)
     revision = Column(Integer, nullable=False)
 
     author_id = Column(Integer, ForeignKey('tg_user.user_id'), nullable=True)
     author = relation('User')
 
-    value = Column(UnicodeText, default='')
+    value = Column(UnicodeText, default=u'')
 
     @property
     def _properties(self):
@@ -159,12 +179,20 @@ class ContentData(DeclarativeBase):
             config.readfp(StringIO(self.value))
         return config
 
+    def property_is_binary(self, prop):
+        return self.get_property(None, prop).startswith('data:')
+
+    def get_binary_property_mimetype(self, prop):
+        return self.get_property(None, prop).rsplit(';')[0].rsplit(':')[-1]
+
     def _update_properties(self, properties):
         data = StringIO()
         properties.write(data)
         self.value = data.getvalue()
 
     def get_property(self, section, prop):
+        if section == None:
+            section = self._properties.sections()[0]
         return self._properties.get(section, prop)
 
     def set_property(self, section, prop, value):
@@ -178,19 +206,50 @@ class ContentData(DeclarativeBase):
     def html(self):
         return BeautifulSoup(self.value)
 
+    @staticmethod
+    def decode(data):
+        config = ConfigParser()
+        config.readfp(StringIO(data))
+
+        section_name = config.sections()[0]
+        attributes = config.options(section_name)
+
+        parsed = {}
+        for attr in attributes:
+            parsed[attr] = config.get(section_name, attr)
+
+        return parsed
+
+    @staticmethod
+    def encode(attrs):
+        config = ConfigParser()
+        config.add_section('acr_data')
+
+        for name, value in attrs.iteritems():
+            config.set('acr_data', name, value)
+
+        s = StringIO()
+        config.write(s)
+        return s.getvalue()
+        
 class View(DeclarativeBase):
     __tablename__ = 'acr_cms_view'
 
     uid = Column(Integer, primary_key=True)
     name = Column(Unicode(30), nullable=False, index=True, unique=True)
-    type = Column(Unicode(32), nullable=False, default='text')
-    code = Column(UnicodeText, default='')
+    type = Column(Unicode(32), nullable=False, default=u'text')
+    code = Column(UnicodeText, default=u'')
 
     @property
     def properties(self):
-        config = ConfigParser()
+        try:
+            config = ConfigParser(dict_type=MultiDict)
+        except:
+            config = ConfigParser()
+
         if self.code:
             config.readfp(StringIO(self.code))
+
         return config
 
 class Page(DeclarativeBase):
@@ -198,7 +257,7 @@ class Page(DeclarativeBase):
 
     uid = Column(Integer, primary_key=True)
     uri = Column(Unicode(32), index=True)
-    title = Column(Unicode(30), default='')
+    title = Column(Unicode(30), default=u'')
 
     parent_uid = Column(Integer, ForeignKey('acr_cms_page.uid', ondelete="CASCADE"))
     children = relation('Page', backref=backref('parent', remote_side='Page.uid'))
@@ -232,6 +291,21 @@ class Page(DeclarativeBase):
             yield ancestor
             ancestor = ancestor.parent
 
+    def getattr(self, name):
+        attr = DBSession.query(Attribute).filter_by(page=self)\
+                                         .filter_by(name=name).first()
+        if attr:
+            return attr.value
+        else:
+            return None
+
+    def setattr(self, name, value):
+        attr = DBSession.query(Attribute).filter_by(page=self)\
+                                         .filter_by(name=name).first()
+        if attr:
+            attr.value = value
+        else:
+            DBSession.add(Attribute(name=name, value=value, page=self))
 
 class Slice(DeclarativeBase):
     class Hooks(MapperExtension):
@@ -244,8 +318,8 @@ class Slice(DeclarativeBase):
 
     uid = Column(Integer, primary_key=True)
     name = Column(Unicode(30), nullable=False, index=True, unique=True)
-    zone = Column(Unicode(30), default='main')
-    view = Column(Unicode(30), default='html')
+    zone = Column(Unicode(30), default=u'main')
+    view = Column(Unicode(30), default=u'html')
     slice_order = Column(Integer, default=0)
 
     tags = relation('Tag', secondary=tag_slice_map)
@@ -257,10 +331,13 @@ class Slice(DeclarativeBase):
     def desc(self):
         return '%i : %s, %s' % (self.uid, self.view, self.content_uid)
 
-    def preview(self, hightlight=None, omit_link=False):
+    def preview(self, hightlight=None, omit_link=False, data=None):
         from libacr.lib import url as acr_url
+        
+        if not data:
+            data = self.content.data
 
-        soup = BeautifulSoup(self.content.data)
+        soup = BeautifulSoup(data)
         text = soup.findAll(text=True)
         text = ' '.join(text)
 
