@@ -2,20 +2,19 @@ from libacr.views.slice_group import SliceGroupRenderer
 from routes import url_for
 from libacr.lib import url
 from webhelpers.feedgenerator import Rss201rev2Feed
-import ConfigParser, StringIO
 from libacr.model.core import DBSession
 from libacr.model.content import Slice, Content
+from libacr.views.manager import ViewsManager
 from sqlalchemy.orm import join
 
 __all__ = ['rss_for_slicegroup']
 
 def get_slicegroup_members(slice):
-    config = ConfigParser.ConfigParser()
-    config.readfp(StringIO.StringIO(slice.content.data))
-    filter_tag = config.get('group', 'filter_tag')
+    config = ViewsManager.find_view('slicegroup').to_dict(slice.content.data)
+    filter_tag = config.get('filter_tag', '')
     
     try:
-        orderer = config.get('group', 'orderer')
+        orderer = config.get('orderer')
         orderer = SliceGroupRenderer.slice_orderers[orderer]
     except:
         orderer = lambda x : x
