@@ -6,7 +6,6 @@ from comments import *
 from file_entry import *
 from form import *
 from image import *
-from linked_image import *
 from video import *
 from search import *
 from user_defined_views import *
@@ -21,7 +20,8 @@ class ViewsManager(object):
                       SliceGroupRenderer(), CommentsRenderer(),
                       TwitterRenderer(), FileRenderer(),
                       FormRenderer(), ImageRenderer(), SearchRenderer(),
-                      VideoRenderer(), ScriptRenderer(), LinkedImageRenderer()]
+                      VideoRenderer(), ScriptRenderer(), TagCloudRenderer(),
+                      BlogPostRenderer()]
 
         self.forms = {}
 
