@@ -1,26 +1,26 @@
-import ConfigParser
 from tg import tmpl_context
-import StringIO
 from libacr.lib import url as acr_url
 from libacr.lib import language
 from genshi.template import MarkupTemplate
 
 from libacr.model.core import DBSession
 from libacr.model.content import Page
+from libacr.model.assets import Asset
 import os
 from tg import config
 import Image
 
-from libacr.mediaWorker import generate_thumb_cmd, convert_video
 import tempfile
 import tw.forms as twf
+from base import EncodedView
+from libacr.form_fields import AssetField
 
-class VideoRenderer(object):       
+class VideoRenderer(EncodedView):
     def __init__(self):
         self.name = 'video'
-        self.exposed = 'RDisk'
+        self.exposed = True
 
-        self.form_fields = [twf.TextField('path', label_text="Path:",
+        self.form_fields = [AssetField('path', label_text="Asset:",
                                                   validator=twf.validators.String(not_empty=True, strip=True)),
                             twf.TextField('title', label_text="Title:",
                                                   validator=twf.validators.String(not_empty=True, strip=True)),
@@ -31,30 +31,25 @@ class VideoRenderer(object):
                             twf.TextField('size', label_text="Size (auto or 320x240):", default='auto',
                                                   validator=twf.validators.String(not_empty=True, strip=True))]
 
-    def to_dict(self, data):
-        config = ConfigParser.ConfigParser()
-        config.readfp(StringIO.StringIO(data))
+    def adapt_path(self, path):
+        if path.startswith('asset'):
+            asset = DBSession.query(Asset).filter_by(uid=path.split(':')[1]).first()
+            return (asset.url+'.ogv', asset.url+'.mov')
+        else:
+            video_p=os.path.splitext(path)[0]
+            name_video=video_p.split('/')[2]
+            return ("/rdisk/video/video_%s.ogg" % video_name, 
+                    "/rdisk/video/video_%s.mov" % video_name)
 
-        d = {'show_title' : config.get('video', 'show_title'),
-                   'path' : config.get('video', 'path'),
-                  'title' : config.get('video', 'title'),
-                   'size' : config.get('video', 'size')}
+    def thumbnail(self, video_path, poster=False):
+        if image_path.startswith('asset'):
+            asset = DBSession.query(Asset).filter_by(uid=image_path.split(':')[1]).first()
+            if not poster:
+                return asset.thumb_url('medium')
+            else:
+                return asset.thumb_url('video')
 
-        return d
-
-    def from_dict(self, dic):
-        config = ConfigParser.ConfigParser()
-        config.add_section('video')
-        config.set('video', 'show_title', dic['show_title'])
-        config.set('video', 'path', dic['path'])
-        config.set('video', 'size', dic['size'])
-        config.set('video', 'title', dic['title'])
-
-        s = StringIO.StringIO()
-        config.write(s)
-        return s.getvalue()
-
-    def thumbnail(self, video_path):
+        #Backward compatible for videos uploaded from RDisk
         if video_path.startswith('/rdisk/'):
             video_path = video_path[len('/rdisk/'):]
 
@@ -62,24 +57,15 @@ class VideoRenderer(object):
         thumb_path = os.path.splitext(video_path)[0] + '.png'
         thumb_uri = '/rdisk/thumbs/'+thumb_path
         thumb_full_path = os.path.join(config.get('public_dir'), 'rdisk', 'thumbs', thumb_path)
-
-        if not os.path.exists(thumb_full_path):
-            os.system(generate_thumb_cmd % (full_path, thumb_full_path))
-
-            video_name = os.path.split(video_path)[-1]
-            video_name = os.path.splitext(video_name)[0]
-            convert_video(config.get('public_dir'), video_name, full_path)
-
         return thumb_uri
   
     def preview(self, page, slice, data):
-        config = ConfigParser.ConfigParser()
-        config.readfp(StringIO.StringIO(data))
+        config = self.to_dict(data)
 
-        video_path = config.get('video', 'path')
-        video_title = config.get('video', 'title')
-        video_size = config.get('video', 'size')
-        video_show = config.get('video', 'show_title')
+        video_path = config.get('path')
+        video_title = config.get('title')
+        video_size = config.get('size', 'auto')
+        video_show = config.get('show_title')
         
         uri = slice.page and slice.page.uri or video_path
         video = '<div class="acr_video_preview">'
@@ -91,7 +77,7 @@ class VideoRenderer(object):
         if video_path.startswith('/rdisk/'):
             video_path = video_path[len('/rdisk/'):]
 
-        video += '<img src="/rdisk/thumbs/%s"/>' % self.thumbnail(video_path)
+        video += '<img src="%s"/>' % self.thumbnail(video_path)
         
         if video_show == 'bottom':
            video += '<div class="video_title">%s</div>' % video_title
@@ -100,29 +86,26 @@ class VideoRenderer(object):
         return video
    
     def render(self, page, slice, data):
-        config = ConfigParser.ConfigParser()
-        config.readfp(StringIO.StringIO(data))
-
-        path= config.get('video', 'path')
-        title= config.get('video', 'title')
-        size= config.get('video', 'size')
-        show_title= config.get('video', 'show_title')
+        config = self.to_dict(data)
+        
+        path= config.get('path')
+        title= config.get('title')
+        size= config.get('size', 'auto')
+        show_title= config.get('show_title')
         
         video = '<div class="acr_video">'
         if show_title=='top':
            video += '<div class="video_title">%s</div>' %(title)
 
-        video_p=os.path.splitext(path)[0]
-        name_video=video_p.split('/')[2]
-        
         if size == 'auto':
-           video += '<video  controls="true" poster="%s">' % self.thumbnail(path)
+           video += '<video  controls="true" poster="%s">' % self.thumbnail(path, poster=True)
         else: 
            size2 = size.split('x')
-           video += '<video  controls="true" poster="%s" style="width:%spx;height:%spx;">'% (self.thumbnail(path),size2[0],size2[1])
+           video += '<video  controls="true" poster="%s" style="width:%spx;height:%spx;">'% (self.thumbnail(path, poster=True),size2[0],size2[1])
 
-        video += '<source src="/rdisk/video/video_%s.ogg" type="video/ogg"/>'% (name_video)
-        video += '<source src="/rdisk/video/video_%s.mov"/>'% (name_video)
+        ogv_url, mov_url = self.adapt_path(path)
+        video += '<source src="%s" type="video/ogg"/>'% (ogv_url)
+        video += '<source src="%s"/>'% (mov_url)
         video += '</video>'
 
         if show_title=='bottom':
